@@ -47,9 +47,13 @@ def tuxrun_args_generate(monkeypatch):
 
 
 @pytest.fixture
-def lava_run(mocker):
-    Popen = mocker.patch("subprocess.Popen")
-    proc = Popen.return_value
+def lava_run_call(mocker):
+    return mocker.patch("subprocess.Popen")
+
+
+@pytest.fixture
+def lava_run(lava_run_call, mocker):
+    proc = lava_run_call.return_value
     proc.wait.return_value = 0
     proc.communicate.return_value = (mocker.MagicMock(), mocker.MagicMock())
     return proc
@@ -87,9 +91,12 @@ def test_almost_real_run(tuxrun_args, lava_run, capsys):
         [],
         ["--device", "qemu-armv7", "--device-dict", "device.yaml"],
         ["--device", "qemu-armv7", "--dtb", "bla.dtb"],
+        ["--device", "qemu-arm64", "--bios", "bios.bin"],
         ["--kernel", "https://storage.tuxboot.com/i386/bzImage"],
         ["--device-dict", "device.yaml"],
         ["--definition", "definition.yaml"],
+        ["--device", "fvp-morello-android", "--mcp-fw", "mcp.bin"],
+        ["--device", "fvp-morello-android", "--test", "multicore"],
     ],
 )
 def test_command_line_errors(argv, capsys, monkeypatch):
@@ -186,3 +193,73 @@ def test_invalid_tuxmake_directory(monkeypatch, tmp_path, capsys):
         assert exit.status_code != 0
     _, err = capsys.readouterr()
     assert "metadata.json" in err
+
+
+def test_modules(monkeypatch, lava_run_call, lava_run):
+    monkeypatch.setattr(
+        "sys.argv",
+        [
+            "tuxrun",
+            "--kernel=bzImage",
+            "--device=qemu-x86_64",
+            "--modules=/path/to/foo.tar.gz",
+        ],
+    )
+    assert main() == 0
+    lava_run_call.assert_called()
+    args = lava_run_call.call_args[0][0]
+    assert "/path/to/foo.tar.gz:/path/to/foo.tar.gz:ro" in args
+
+
+def test_overlays(monkeypatch, lava_run_call, lava_run):
+    monkeypatch.setattr(
+        "sys.argv",
+        [
+            "tuxrun",
+            "--kernel=bzImage",
+            "--device=qemu-x86_64",
+            "--overlay=/path/to/stuff.tar.gz",
+            "--overlay=/path/to/morestuff.tar.gz",
+        ],
+    )
+    assert main() == 0
+    lava_run_call.assert_called()
+    args = lava_run_call.call_args[0][0]
+    assert "/path/to/stuff.tar.gz:/path/to/stuff.tar.gz:ro" in args
+    assert "/path/to/morestuff.tar.gz:/path/to/morestuff.tar.gz:ro" in args
+
+
+def test_custom_commands(monkeypatch, run):
+    monkeypatch.setattr(
+        "sys.argv",
+        ["tuxrun", "--kernel=bzImage", "--device=qemu-x86_64", "cat", "/etc/hostname"],
+    )
+    main()
+    run.assert_called()
+    options = run.call_args[0][0]
+    assert "command" in options.tests
+    assert options.command == ["cat", "/etc/hostname"]
+
+
+def test_list_devices(mocker, monkeypatch, capsys):
+    monkeypatch.setattr(
+        "sys.argv",
+        ["tuxrun", "--list-devices"],
+    )
+    mocker.patch("argparse.ArgumentParser.exit")
+    main()
+    stdout, stderr = capsys.readouterr()
+    assert stdout == ""
+    assert "qemu-i386" in stderr
+
+
+def test_list_tests(mocker, monkeypatch, capsys):
+    monkeypatch.setattr(
+        "sys.argv",
+        ["tuxrun", "--list-tests"],
+    )
+    mocker.patch("argparse.ArgumentParser.exit")
+    main()
+    stdout, stderr = capsys.readouterr()
+    assert stdout == ""
+    assert "ltp-smoke" in stderr
