@@ -1,9 +1,17 @@
-from urllib.parse import urlparse
+# -*- coding: utf-8 -*-
+# vim: set ts=4
+#
+# Copyright 2021-present Linaro Limited
+#
+# SPDX-License-Identifier: MIT
+
+import os
 import re
 import requests
-import os
 import sys
 import time
+from urllib.parse import urlparse
+
 from tuxrun.utils import ProgressIndicator, NoProgressIndicator
 from tuxrun.xdg import get_cache_dir
 
@@ -17,6 +25,7 @@ KERNELS = {
     "qemu-mips32el": "https://storage.tuxboot.com/mips32el/vmlinux",
     "qemu-mips64": "https://storage.tuxboot.com/mips64/vmlinux",
     "qemu-mips64el": "https://storage.tuxboot.com/mips64el/vmlinux",
+    "qemu-ppc32": "https://storage.tuxboot.com/ppc32/uImage",
     "qemu-ppc64": "https://storage.tuxboot.com/ppc64/vmlinux",
     "qemu-ppc64le": "https://storage.tuxboot.com/ppc64le/vmlinux",
     "qemu-riscv64": "https://storage.tuxboot.com/riscv64/Image",
@@ -34,6 +43,7 @@ ROOTFS = {
     "qemu-mips32": "https://storage.tuxboot.com/mips32/rootfs.ext4.zst",
     "qemu-mips64el": "https://storage.tuxboot.com/mips64el/rootfs.ext4.zst",
     "qemu-mips64": "https://storage.tuxboot.com/mips64/rootfs.ext4.zst",
+    "qemu-ppc32": "https://storage.tuxboot.com/ppc32/rootfs.ext4.zst",
     "qemu-ppc64": "https://storage.tuxboot.com/ppc64/rootfs.ext4.zst",
     "qemu-ppc64le": "https://storage.tuxboot.com/ppc64le/rootfs.ext4.zst",
     "qemu-riscv64": "https://storage.tuxboot.com/riscv64/rootfs.ext4.zst",
@@ -42,12 +52,19 @@ ROOTFS = {
 }
 
 
+TEST_DEFINITIONS = "https://storage.tuxboot.com/test-definitions/2021.04.tar.zst"
+
+
 def get_rootfs(
     device, rootfs: str = None, progress: ProgressIndicator = NoProgressIndicator()
 ) -> str:
     return __download_and_cache__(rootfs or ROOTFS[device], progress)
 
 
+def get_test_definitions(progress: ProgressIndicator = NoProgressIndicator()):
+    return __download_and_cache__(TEST_DEFINITIONS, progress)
+
+
 def __download_and_cache__(
     url: str, progress: ProgressIndicator = NoProgressIndicator()
 ):
